<?php
if (class_exists('WP_Customize_Control')) {

    /**
     * Sortable multi check boxes custom control.
     * @since 1.0
     * @author inkthemes.com
     * @copyright Copyright (c) 2015, inkthemes.com
     */
    class Inkthemes_Customize_Control_Sortable_Checkboxes extends WP_Customize_Control {

        /**
         * Control Type
         */
        public $type = 'ink-multicheck-sortable';

        /**
         * Render Settings
         */
        public function render_content() {

            /* if no choices, bail. */
            if (empty($this->choices)) {
                return;
            }
            if (!empty($this->label)) {
                ?>
                <span class="customize-control-title"><?php echo esc_html($this->label); ?></span>
                <?php
            } // add label if needed.

            if (!empty($this->description)) {
                ?>
                <span class="description customize-control-description"><?php echo $this->description; ?></span>
                <?php
            } // add desc if needed.
            /* Data */
            $values = explode(',', $this->value());
            $choices = $this->choices;

            /* If values exist, use it. */
            $options = array();
            if ($values) {

                /* get individual item */
                foreach ($values as $value) {

                    /* separate item with option */
                    $value = explode(':', $value);

                    /* build the array. remove options not listed on choices. */
                    if (array_key_exists($value[0], $choices)) {
                        $options[$value[0]] = $value[1] ? '1' : '0';
                    }
                }
            }
            /* if there's new options (not saved yet), add it in the end. */
            foreach ($choices as $key => $val) {

                /* if not exist, add it in the end. */
                if (!array_key_exists($key, $options)) {
                    $options[$key] = '0'; // use zero to deactivate as default for new items.
                }
            }
            ?>

            <ul class="ink-multicheck-sortable-list">

                <?php foreach ($options as $key => $value) { ?>

                    <li>
                        <label>
                            <input name="<?php echo esc_attr($key); ?>" class="ink-multicheck-sortable-item" type="checkbox" value="<?php echo esc_attr($value); ?>" <?php checked($value); ?> />
                            <?php echo esc_html($choices[$key]); ?>
                        </label>
                        <i class="dashicons dashicons-menu ink-multicheck-sortable-handle"></i>
                    </li>

                <?php } // end choices.      ?>

                <li class="ink-hideme">
                    <input type="hidden" class="ink-multicheck-sortable" <?php $this->link(); ?> value="<?php echo esc_attr($this->value()); ?>" />
                </li>

            </ul><!-- .ink-multicheck-sortable-list -->


            <?php
        }

    }

    class Inkthemes_Customize_Alpha_Color_Control extends WP_Customize_Control {

        /**
         * Official control name.
         */
        public $type = 'alpha-color';

        /**
         * Add support for palettes to be passed in.
         *
         * Supported palette values are true, false, or an array of RGBa and Hex colors.
         */
        public $palette;

        /**
         * Add support for showing the opacity value on the slider handle.
         */
        public $show_opacity;

        /**
         * Enqueue scripts and styles.
         *
         * Ideally these would get registered and given proper paths before this control object
         * gets initialized, then we could simply enqueue them here, but for completeness as a
         * stand alone class we'll register and enqueue them here.
         */

        /**
         * Render the control.
         */
        public function render_content() {
// Process the palette
            if (is_array($this->palette)) {
                $palette = implode('|', $this->palette);
            } else {
// Default to true.
                $palette = ( false === $this->palette || 'false' === $this->palette ) ? 'false' : 'true';
            }
// Support passing show_opacity as string or boolean. Default to true.
            $show_opacity = ( false === $this->show_opacity || 'false' === $this->show_opacity ) ? 'false' : 'true';
// Begin the output.
            ?>
            <label>
                <?php
                // Output the label and description if they were passed in.
                if (isset($this->label) && '' !== $this->label) {
                    echo '<span class="customize-control-title">' . sanitize_text_field($this->label) . '</span>';
                }
                if (isset($this->description) && '' !== $this->description) {
                    echo '<span class="description customize-control-description">' . sanitize_text_field($this->description) . '</span>';
                }
                ?>
                <input class="alpha-color-control" type="text" data-show-opacity="<?php echo $show_opacity; ?>" data-palette="<?php echo esc_attr($palette); ?>" data-default-color="<?php echo esc_attr($this->settings['default']->default); ?>" <?php $this->link(); ?>  />
            </label>
            <?php
        }

    }

    class Inkthemes_Customize_AD extends WP_Customize_Control {

        public $image_url;
        public $link_url;

        public function render_content() {
            ?>
            <label style="margin-top: 20px;display: block; color: #298cba !important;">
                <?php
                // Output the label and description if they were passed in.
                if (isset($this->label) && '' !== $this->label) {
                    echo '<span class="customize-control-title">' . sanitize_text_field($this->label) . '</span>';
                }
                if (isset($this->description) && '' !== $this->description) {
                    echo '<span class="description customize-control-description">' . sanitize_text_field($this->description) . '</span>';
                }
                if (isset($this->image_url) && '' !== $this->image_url) {
                    echo '<span class="customize-control-img"><a target="_new" href="' . (isset($this->link_url) && $this->link_url != "" ? $this->link_url : '#') . '"><img src="' . ($this->image_url) . '" alt="inkthemes_ad"/></a></span>';
                }
                ?>
            </label>
            <?php
        }

    }

    /**
     * Andrina upgrade control 
     */
    class Andrina_Upgrade_control extends WP_Customize_Control {

        /**
         * Control Type
         */
        public $type = 'upgrade_msg';

        /**
         * Enqueue scripts and styles.
         *
         * Ideally these would get registered and given proper paths before this control object
         * gets initialized, then we could simply enqueue them here, but for completeness as a
         * stand alone class we'll register and enqueue them here.
         */
        public function enqueue() {
            
        }

        /**
         * Render Settings
         */
        public function render_content() {
            ?>
            <label>
                <?php
                // Output the label and description if they were passed in.
                if (isset($this->label) && '' !== $this->label) {
                    echo '<span class="customize-control-title lock-tab">' . sanitize_text_field($this->label) . '</span>';
                }
                if (isset($this->description) && '' !== $this->description) {
                    echo '<span class="description customize-control-description upgrade">' . wp_kses_post($this->description) . '</span>';
                }
                ?>
            </label>
            <?php
        }

    }

    class Andrina_Upgrade_control2 extends WP_Customize_Control {

        /**
         * Control Type
         */
        public $type = 'upgrade_msg2';

        /**
         * Enqueue scripts and styles.
         *
         * Ideally these would get registered and given proper paths before this control object
         * gets initialized, then we could simply enqueue them here, but for completeness as a
         * stand alone class we'll register and enqueue them here.
         */
        public function enqueue() {
            
        }

        /**
         * Render Settings
         */
        public function render_content() {
            ?>
            <label>
                <?php
                // Output the label and description if they were passed in.
                if (isset($this->label) && '' !== $this->label) {
                    echo '<span class="customize-control-title">' . sanitize_text_field($this->label) . '</span>';
                }
                if (isset($this->description) && '' !== $this->description) {
                    echo '<span class="description customize-control-description upgrade">' . wp_kses_post($this->description) . '</span>';
                }
                ?>
            </label>
            <?php
        }

    }

}




